import { __awaiter } from 'tslib';
import * as i0 from '@angular/core';
import { Injectable } from '@angular/core';
import { Subject } from 'rxjs';
import { PicovoiceWorker } from '@picovoice/picovoice-web';
import { WebVoiceProcessor } from '@picovoice/web-voice-processor';

class PicovoiceService {
    constructor() {
        this.wakeWordDetection$ = new Subject();
        this.inference$ = new Subject();
        this.contextInfo$ = new Subject();
        this.isLoaded$ = new Subject();
        this.isListening$ = new Subject();
        this.error$ = new Subject();
        this.picovoice = null;
    }
    init(accessKey, keyword, porcupineModel, context, rhinoModel, options = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            if (options.processErrorCallback) {
                console.warn('The `processErrorCallback` option is only supported in the Picovoice Web SDK. ' +
                    'Use the `error` state to monitor for errors in the Angular SDK.');
            }
            try {
                if (!this.picovoice) {
                    PicovoiceWorker.setSdk('angular');
                    this.picovoice = yield PicovoiceWorker.create(accessKey, keyword, (detection) => this.wakeWordDetection$.next(detection), porcupineModel, context, (inference) => this.inference$.next(inference), rhinoModel, Object.assign(Object.assign({}, options), { processErrorCallback: (error) => this.error$.next(error) }));
                    this.contextInfo$.next(this.picovoice.contextInfo);
                    this.isLoaded$.next(true);
                    this.error$.next(null);
                }
            }
            catch (error) {
                this.error$.next(error);
            }
        });
    }
    start() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.picovoice === null) {
                this.error$.next(new Error('Picovoice has not been initialized or has been released'));
                return;
            }
            try {
                yield WebVoiceProcessor.subscribe(this.picovoice);
                this.isListening$.next(true);
                this.error$.next(null);
            }
            catch (error) {
                this.error$.next(error);
                this.isListening$.next(false);
            }
        });
    }
    stop() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.picovoice === null) {
                this.error$.next(new Error('Picovoice has not been initialized or has been released'));
                return;
            }
            try {
                yield WebVoiceProcessor.unsubscribe(this.picovoice);
                this.isListening$.next(false);
                this.error$.next(null);
            }
            catch (error) {
                this.error$.next(error);
                this.isListening$.next(true);
            }
        });
    }
    release() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.picovoice) {
                yield this.stop();
                this.picovoice.terminate();
                this.picovoice = null;
                this.isLoaded$.next(false);
            }
        });
    }
    ngOnDestroy() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.release();
        });
    }
}
PicovoiceService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PicovoiceService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
PicovoiceService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PicovoiceService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.12", ngImport: i0, type: PicovoiceService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: function () { return []; } });

/*
 * Public API Surface of picovoice-angular
 */

/**
 * Generated bundle index. Do not edit.
 */

export { PicovoiceService };
//# sourceMappingURL=picovoice-picovoice-angular.mjs.map
